@@ -39,6 +39,7 @@
 #ifdef DEBUG
 #include "comp_factor.h"
 #include "comp_bitsums.h"
+#include "comp_textrle.h"
 #endif
 #include "comp_range.h"
 #include "comp_snibble.h"
@@ -72,11 +73,13 @@ int (*(algorithms[256]))()={    comp_plain_algo,
 #ifdef DEBUG
 				comp_factor_algo,
 				comp_bitsums_algo,
+				comp_textrle_algo,
 #else
 				DACT_FAILED_ALGO,
 				DACT_FAILED_ALGO,
+				DACT_FAILED_ALGO,
 #endif
-				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
+				NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
 				NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL,
@@ -135,9 +138,11 @@ char *algorithm_names[256]={	"Uncompressed",
 #ifdef DEBUG
 				"Factor Compression",
 				"Bitsums Compression",
+				"Text RLE Compression",
 #else
 				"Unsupported Algorithm (factor)",
 				"Unsupported Algorithm (bitsums)",
+				"Unsupported Algorithm (textrle)",
 #endif
 				NULL
 			};
