@@ -73,16 +73,10 @@ unsigned char cipher_chaos_getbyte(double *x, int y) {
 	unsigned int b;
 
 	NORM(*x);
+	FIX(*x);
 	BEST(*x,y);
-	if (i==30) {
-		for (b=0;b<313;b++) {
-			BEST(*x,y);
-			*x=(double) (R(*x)*(1-*x));
-		}
-		i=0;
-	} else {
-		i++;
-	}
-
+	*x=(double) (R(*x)*(1-*x));
+	i++;
+SPOTVAR_NUM(y);
 	return((unsigned char) y);
 }
