@@ -22,9 +22,10 @@
 #define _CIPHER_CHAOS_H
 #include "dact.h"
 
-#define R(x) 4*x
+#define R(x) 4*(x)
 #define NORM(x) { x+=0.000001; while(x<1) x*=10; while(x>=1) x/=10; }
-#define BEST(x,y) { y=((int) ((x)*100000))&0xff; }
+#define BEST(x,y) { y=((int) ((x)*10000))&0xff; }
+#define FIX(x) { x=(((double) ((int) ((x)*100000)))/100000); }
 
 int cipher_chaos(const char *inblock, char *outblock, const int blksize, char *key, const int mode);
 int cipher_chaos_init(const int mode, char *key);
