@@ -92,55 +92,35 @@ int cipher_sub_init_getkey(const int mode, char *key) {
 	return(-1);
 }
 
-int cipher_sub_encrypt(const char *inblk, char *outblk, int blksize, char *key) {
-	char *tmpbuf;
-	tmpbuf=cryptdata(key,inblk,blksize);
-	memcpy(outblk,tmpbuf,blksize);
-	free(tmpbuf);
-	return(blksize);
-}
-
-int cipher_sub_decrypt(const char *inblk, char *outblk, int blksize, char *key) {
-	char *tmpbuf;
-	tmpbuf=decryptdata(key,inblk,blksize);
-	memcpy(outblk,tmpbuf,blksize);
-	free(tmpbuf);
-	return(blksize);
-}
-
-char *cryptdata(unsigned char key[257], const unsigned char *data, int size) {
+int cipher_sub_encrypt(const unsigned char *inblk, unsigned char *outblk, int blksize, unsigned char *key) {
 	int i,mod;
-	char *result;
 	static int keyoffset=0;
-	result=malloc(size);
 
 	mod=(int) key[0];
-	for (i=0;i<size;i++) {
+	for (i=0;i<blksize;i++) {
 		if (!(i%mod)) {
 			keyoffset=((keyoffset+1)&0xff);
 		}
-		result[i]=key[((((int) data[i])+keyoffset)&0xff)+1];
+		outblk[i]=key[((((int) inblk[i])+keyoffset)&0xff)+1];
 	}
-	return(result);
+	return(blksize);
 }
 
-char *decryptdata(unsigned char key[257], const unsigned char *data, int size) {
+int cipher_sub_decrypt(const unsigned char *inblk, unsigned char *outblk, int blksize, unsigned char *key) {
 	int i,mod,x;
 	char reversekey[256];
-	char *result;
 	static int keyoffset=0;
 
 	mod=(int) key[0];
-	result=malloc(size);
 	for (i=1;i<257;i++) reversekey[(int) key[i]]=(i-1);
-	for (i=0;i<size;i++) {
+	for (i=0;i<blksize;i++) {
 		if (!(i%mod)) {
 			keyoffset=((keyoffset+1)&0xff);
 			for (x=0;x<256;x++) reversekey[(int) key[((x+keyoffset)&0xff)+1]]=x;
 		}
-		result[i]=reversekey[(int) data[i]];
+		outblk[i]=reversekey[(int) inblk[i]];
 	}
-	return(result);
+	return(blksize);
 }
 
 char *generatekey(void) {
