@@ -23,10 +23,11 @@
 #include "cipher_chaos.h"
 #include "cipher_sub.h"
 #include "cipher_serpent.h"
+#include "cipher_psub.h"
 
 
 #ifndef CIPHER_COUNT
-#define CIPHER_COUNT 4
+#define CIPHER_COUNT 5
 #endif
 
 
@@ -38,6 +39,7 @@ int (*(ciphers[CIPHER_COUNT]))()={
 #else
 	NULL,
 #endif
+	cipher_psub,
 	NULL
 };
 
@@ -49,6 +51,7 @@ char *ciphers_name[CIPHER_COUNT]={ 		/* These must be lower-cased */
 #else
 	NULL,
 #endif
+	"psubst",
 	NULL
 };
 
