@@ -88,6 +88,7 @@ int print_help(int argc, char **argv) {
 	printf("  -b NN       Use a block size of NN bytes for compression.\n");
 	printf("  -e NN       Exclude algorithm NN from being used.\n");
 	printf("  -m CONF     Load config file CONF.\n");
+	printf("  -o FILE     Send output to FILE.\n");
 	printf("  -u URL      Specify download location as URL.\n");
 	printf("  -p URL      Parse URL and print results, then exit.\n");
 	printf("  -D DESC     Specify a description of DESC.\n");
@@ -147,6 +148,8 @@ void dact_loadconfig(const char *path, char *options) {
 				}
 #endif
 				break;
+			case 209445231: /* exclude_algo */
+				break;
 			case 168825941: /* block_size */
 				DACT_BLK_SIZE=atoi2(item_buf[1]);
 				break;
@@ -1140,8 +1143,7 @@ int main(int argc, char **argv) {
 				options[DACT_OPT_HDONLY]=!options[DACT_OPT_HDONLY];
 				break;
 			case 'o':
-				out_file=malloc(strlen(optarg)+1);
-				strcpy(out_file,optarg);
+				out_file=parse_url_subst(optarg, "");
 				break;
 			case 'N':
 				return(dact_upgrade(options,crcs));
@@ -1264,6 +1266,7 @@ int main(int argc, char **argv) {
 				continue;
 			}
 			if (out_file!=NULL) {
+				if (!strcmp("-",out_file)) options[DACT_OPT_STDOUT]=1;
 /*
  *
  * This is a bad thing if this program is SUID root, which it NEVER EVER 
